{ pkgs ? import <nixpkgs> {}}:
with import <nixpkgs> {};


let
  artiqpkgs = import ./default.nix { inherit pkgs; };
  vivado = import ./vivado.nix { inherit pkgs; };
  sipyco = python3Packages.buildPythonPackage rec {
    pname = "sipyco";
    version = "0.1";
    src = /home/thomp/scratch/sipyco;
    propagatedBuildInputs = [ pkgs.python3Packages.statsmodels ];
    doCheck = false;
    };
  MetaArray = python3Packages.buildPythonPackage rec {
    pname = "MetaArray";
    version = "2.0.2";
    src = /home/thomp/scratch/metaarray;
    propagatedBuildInputs = [ pkgs.python3Packages.numpy pkgs.python3Packages.h5py ];
    };
  artiq_comtools = python3Packages.buildPythonPackage rec {
    pname = "artiq-comtools";
    version = "0.1";
    src = /home/thomp/scratch/artiq-comtools;
    propagatedBuildInputs = [ sipyco pkgs.python3Packages.numpy pkgs.python3Packages.aiohttp  ];
    doCheck = false;
    };
  oitg = python3Packages.buildPythonPackage rec {
    pname = "oitg";
    version = "0.1";
    src = /home/thomp/scratch/oitg;
    propagatedBuildInputs = [ pkgs.python3Packages.statsmodels ];
    doCheck = false;
    };
  python_library = python3Packages.buildPythonPackage rec {
    pname = "python_library";
    version = "0.1";
    src = /home/thomp/scratch/python-library;
    propagatedBuildInputs = [ pkgs.python3Packages.numpy pkgs.python3Packages.scipy pkgs.python3Packages.matplotlib ];
    };
  strontium_library = python3Packages.buildPythonPackage rec {
    pname = "strontium_library";
    version = "0.1";
    src = /home/thomp/scratch/strontium-library;
    propagatedBuildInputs = [ pkgs.python3Packages.numpy pkgs.python3Packages.scipy pkgs.python3Packages.matplotlib pkgs.python3Packages.influxdb];
    };
  artiq_tools = python3Packages.buildPythonPackage rec {
    pname = "artiq_tools";
    version = "0.2";
    src = /home/thomp/scratch/artiq_tools;
    propagatedBuildInputs = [ pkgs.python3Packages.numpy pkgs.python3Packages.typing artiqpkgs.artiq pkgs.python3Packages.pyzmq pkgs.python3Packages.matplotlib strontium_library MetaArray];
    };
  ndscan = python3Packages.buildPythonPackage rec {
    pname = "ndscan";
    version = "0.1";
    src = /home/thomp/scratch/ndscan;
    propagatedBuildInputs = [ artiqpkgs.artiq oitg];
    doCheck = false;
    };
  analysis_library = python3Packages.buildPythonPackage rec {
    pname = "analysis_library";
    version = "0.1";
    src = /home/thomp/scratch/analysis-library;
    propagatedBuildInputs = [ pkgs.python3Packages.h5py pkgs.python3Packages.matplotlib pkgs.python3Packages.scipy pkgs.python3Packages.numpy python_library strontium_library pkgs.python3Packages.uncertainties];
    doCheck = false;
    };
  repo_routines = python3Packages.buildPythonPackage rec {
    pname = "repo_routines";
    version = "0.1";
    src = /home/thomp/scratch/repo_routines;
    propagatedBuildInputs = [ ndscan pkgs.python3Packages.numpy artiqpkgs.artiq strontium_library];
    doCheck = false;
    };


in
  pkgs.mkShell {
    buildInputs = [
      vivado
      sipyco
      MetaArray
      artiq_comtools
      artiq_tools
      analysis_library
      python_library
      strontium_library
      repo_routines
      ndscan
      pkgs.gnumake
      (pkgs.python3.withPackages(ps: (with ps; [ jinja2 jsonschema numpy paramiko ]) ++ (with artiqpkgs; [ migen microscope misoc jesd204b migen-axi artiq ])))
      artiqpkgs.cargo
      artiqpkgs.rustc
      artiqpkgs.binutils-or1k
      artiqpkgs.binutils-arm
      artiqpkgs.llvm-or1k
      artiqpkgs.openocd
    ];
    shellHook = ''
      export PYTHONPATH="/home/thomp/scratch/metaarray:$PYTHONPATH"
      export PYTHONPATH="/home/thomp/scratch/artiq_tools:$PYTHONPATH"
      export PYTHONPATH="/home/thomp/scratch/oitg:$PYTHONPATH"
      export PYTHONPATH="/home/thomp/scratch/analysis-library:$PYTHONPATH"
      export PYTHONPATH="/home/thomp/scratch/python-library:$PYTHONPATH"
      export PYTHONPATH="/home/thomp/scratch/strontium-library:$PYTHONPATH"
      export PYTHONPATH="/home/thomp/scratch/ndscan:$PYTHONPATH"
      export PYTHONPATH="/home/thomp/scratch/sipyco:$PYTHONPATH"
      export PYTHONPATH="/home/thomp/scratch/artiq-comtools:$PYTHONPATH"
      export PYTHONPATH="/home/thomp/scratch/repo_routines:$PYTHONPATH"
    '';
    TARGET_AR="or1k-linux-ar";
  }
